@@ -13,9 +13,10 @@
 DCV_CONNECT_SCRIPT = "/opt/parallelcluster/scripts/pcluster_dcv_connect.sh"
 
 
-def get_supported_dcv_os():
+def get_supported_dcv_os(architecture):
     """Return a list of all the operating system supported by DCV."""
-    return ["centos7", "ubuntu1804", "alinux2"]
+    architectures_dict = {"x86_64": ["centos7", "ubuntu1804", "alinux2"], "arm64": ["ubuntu1804", "alinux2"]}
+    return architectures_dict.get(architecture, [])
 
 
 def get_supported_dcv_partition():
